| analysisLambda | R Documentation |
analysisLambda(mcmc_obj, Assumptions = list(), nage, n_proj)
mcmc_obj |
A list, mcmc.obj from ReCAP_sampler result |
Assumptions |
Assumption matrices used in ReCAP_sampler |
nage |
Number of age classes, female first, same as ReCAP_sampler |
n_proj |
Number of years did projection, usually ncol(Harvest_data)-1 |
A list of class "ReCAP_lambda" has same length as number of MCMC samples taken in ReCAP_sampler. Each element is one posterior sample which is a matrix, with each column as years. Rows are anaual growth rate of: maximum possible, uniform age structure, stable age structure, observed age structure w/o harvest, minimum possible, observed growth rate (w/ harvest).
Yunyi Shen
set.seed(42)
ReCAP_sample = ReCAP_sampler(ChicagoDeerdata$Harv.data
,ChicagoDeerdata$Aeri.data
,ChicagoDeerdata$nage
,ChicagoDeerdata$mean.f
,ChicagoDeerdata$mean.s
,ChicagoDeerdata$mean.SRB
,ChicagoDeerdata$mean.H
,ChicagoDeerdata$mean.A
,n.iter = 50,burn.in = 5,thin.by = 1
,Assumptions = ChicagoDeerdata$Assumptions)
analysisoflambda = analysisLambda(ReCAP_sample$mcmc.objs
,ChicagoDeerdata$Assumptions
,ChicagoDeerdata$nage
,ChicagoDeerdata$proj.periods)
Lambda_plot(analysisoflambda,1992,0.05)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.